#pragma once

// Include all necessary headers from the ADTF SDK
#include <adtffiltersdk/adtf_filtersdk.h>

// For simplicity use the necessary namespaces
using namespace adtf::util;
using namespace adtf::ucom;
using namespace adtf::base;
using namespace adtf::streaming;
using namespace adtf::filter;

// To implement a Filter we subclass adtf::filter::cFilter
class cPropertiesFilter: public cFilter
{
public:
    // This macros provides some meta information about our Filter Implementation
    // This will be exposed by the plugin class factory.
    ADTF_CLASS_ID_NAME(cPropertiesFilter,
                       "properties_filter.filter.adtf_guides.cid",
                       "Properties Filter");

public:
    // In the constructor, we setup all aspects of our Filter.
    cPropertiesFilter();

    tResult Init(tInitStage eStage) override;

private:
    // Here are all the Property Variables for our Filter
    property_variable<double> m_fFloatProperty = 3.1415;

    property_variable<uint32_t> m_nGroupedProperty1 = 1;
    property_variable<uint32_t> m_nGroupedProperty2 = 2;

    property_variable<cString> m_strListProperty1 = {"device1"};

    property_variable<cFilename> m_oConfigFilename;

    enum tMyEnum: int32_t
    {
        eFirst = 0,
        eSecond = 1,
        eThird = 2,
    };
    property_variable<tMyEnum> m_eEnumProperty = eFirst;

    property_variable<uint32_t> m_nHiddenProperty = 3;
};
